pub struct Producer<T> { /* private fields */ }Expand description
Publishes a JSON value over a track, choosing snapshots and deltas automatically.
Cheaply clonable: clones share one underlying track and publishing state, like other MoQ producers.
Implementations
Sourceimpl<T> Producer<T>
impl<T> Producer<T>
Sourcepub fn consume(&self) -> TrackConsumer
pub fn consume(&self) -> TrackConsumer
Create a subscriber for the underlying track.
Sourceimpl<T: Serialize> Producer<T>
impl<T: Serialize> Producer<T>
Sourcepub fn new(track: TrackProducer, config: Config) -> Self
pub fn new(track: TrackProducer, config: Config) -> Self
Create a producer that publishes to the given track.