#[non_exhaustive]pub enum Event<T> {
Push {
index: u64,
value: T,
},
Pop(Range<u64>),
Skip(Range<u64>),
}Expand description
One change to the window, as the consumer sees it.
A record is Pushed when it first reaches this consumer. Contiguous ranges are Popped when
they leave the window or Skipped when they were dropped before this consumer saw them.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Push
This record joined the window, at this absolute index.
Pop(Range<u64>)
These records left the window.
Skip(Range<u64>)
These records existed but will never be delivered: they were pushed and dropped while this consumer was behind.